@@ -1,7 +1,9 @@
 package Data::Sah::Resolve;
 
-our $DATE = '2021-02-27'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-07-27'; # DATE
+our $DIST = 'Data-Sah-Resolve'; # DIST
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -99,7 +101,7 @@ sub resolve_schema {
         $res->[1] = \@clsets;
     }
 
-    $res->[2] = $seen if $opts->{return_intermediates};
+    $res->[2]{intermediates} = $seen;
 
     $res;
 }
@@ -119,7 +121,7 @@ Data::Sah::Resolve - Resolve Sah schema
 
 =head1 VERSION
 
-This document describes version 0.008 of Data::Sah::Resolve (from Perl distribution Data-Sah-Resolve), released on 2021-02-27.
+This document describes version 0.009 of Data::Sah::Resolve (from Perl distribution Data-Sah-Resolve), released on 2021-07-27.
 
 =head1 SYNOPSIS
 
@@ -172,23 +174,21 @@ process while accumulating and/or merging the clause sets.
 
 =back
 
-Returns C<< [base_type, clause_sets] >>. If C<return_intermediates> option is
-true, then the third elements will be the list of intermediate schema names.
+Returns C<< [$base_type, \@clause_sets, \%additional] >>.
 
 Example 1: C<int>.
 
-First we normalize to C<< ["int",{},{}] >>. The type is C<int> and it is a
-builtin type (L<Data::Sah::Type::int> exists) so the final result is C<< ["int",
-[]] >>.
+First we normalize to C<< ["int",{}] >>. The type is C<int> and it is a builtin
+type (L<Data::Sah::Type::int> exists) so the final result is C<< ["int", []] >>.
 
 Example 2: C<posint*>.
 
-First we normalize to C<< ["posint",{req=>1},{}] >>. The type is C<posint> and
-it is the name of another schema (L<Sah::Schema::posint>). We retrieve the
-schema which is C<< ["int", {summary=>"Positive integer (1,2,3,...)", min=>1},
-{}] >>. We now try to resolve C<int> and find that it's a builtin type. So the
-final result is: C<< ["int", [ {req=>1}, {summary=>"Positive integer
-(1,2,3,...)", min=>1} ]] >>.
+First we normalize to C<< ["posint",{req=>1}] >>. The type is C<posint> and it
+is the name of another schema (L<Sah::Schema::posint>). We retrieve the
+C<posint> schema which is C<< ["int", {summary=>"Positive integer (1,2,3,...)",
+min=>1}] >>. We now try to resolve C<int> and find that it's a builtin type. So
+the final result is: C<< ["int", [ {req=>1}, {summary=>"Positive integer
+(1,2,3,...)", min=>1} ], {}] >>.
 
 Known options:
 
@@ -201,7 +201,17 @@ is normalized.
 
 =item * merge_clause_sets => bool (default: 1)
 
-=item * return_intermediates => bool
+=back
+
+Additional data returned (in the third element's hash keys):
+
+=over
+
+=item * intermediates
+
+This is an arrayref of intermediate schema names, from the shallowest to the
+deepest. The first element of this arrayref is the original unresolved schema's
+type, then the second is the base schema of the original schema, and so on.
 
 =back
 
